@@ -6,8 +6,9 @@ use v5.20;
 
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
+use Clone        ();
 use Scalar::Util qw( blessed );
 use Ref::Util    qw( is_plain_hashref is_arrayref is_regexpref is_ref );
 use Form::Tiny::Utils 'get_package_form_meta';
@@ -89,13 +90,18 @@ has inherit_optargs_match => (
 
 
 
-has optargs => (
+has _optargs => (
     is       => 'rwp',
     lazy     => 1,
     init_arg => undef,
-    builder  => sub ( $self ) { $self->_build_opt_args->optargs },
+    ## no critic (Subroutines::ProtectPrivateSubs )
+    builder => sub ( $self ) { $self->_build_opt_args->_optargs },
 );
 
+sub optargs ( $self ) {
+    return Clone::clone( $self->_optargs );
+}
+
 has rename => (
     is       => 'rwp',
     lazy     => 1,
@@ -167,7 +173,7 @@ sub _build_opt_args ( $self ) {
         push @optargs, $name, \%spec;
     }
 
-    $self->_set_optargs( \@optargs );
+    $self->_set__optargs( \@optargs );
     $self->_set_rename( \%rename );
     return $self;
 }
@@ -316,8 +322,8 @@ sub _create_options (
                 croak( "$a->[0] and $b->[0] have the same argument order" )
                   if $order == 0;
                 $order;
-              }
-              grep { defined $_->[1]{order} } @optargs
+            }
+            grep { defined $_->[1]{order} } @optargs
         ) ];
 }
 
@@ -509,7 +515,7 @@ CXC::Form::Tiny::Plugin::OptArgs2::Meta - Form metaclass role for OptArgs2
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 DESCRIPTION
 
